@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.1.2;
+package Pcore::Chrome v0.1.3;
 
 use Pcore -dist, -const, -class;
 use Pcore::Chrome::Tab;
@@ -101,9 +101,16 @@ sub run ( $self, @args ) {
             $self->{host} = $args{host};
             $self->{port} = $args{port};
 
-            $cb->($self) if $cb;
+            # wait for chrome
+            $proc->{timer} = AE::timer 3, 0, sub {
+                delete $proc->{timer};
 
-            $blocking_cv->($self) if $blocking_cv;
+                $cb->($self) if $cb;
+
+                $blocking_cv->($self) if $blocking_cv;
+
+                return;
+            };
 
             return;
         },
